
# Example: what happens with external links?

*[ribbity-org/ribbity-test-repo#8](https://github.com/ribbity-org/ribbity-test-repo/issues/8)*

---

[http://github.com/ribbity-org/ribbity](http://github.com/ribbity-org/ribbity) at beginning -

they should be rendered faithfully and turned into a hyperlink. both of these should be hyperlinks in mkdocs:

[http://github.com/ribbity-org/ribbity](http://github.com/ribbity-org/ribbity)

[https://github.com/ribbity-org/ribbity](https://github.com/ribbity-org/ribbity)

they should be left alone if they are in a [markdown link](https://github.com/sourmash-bio/sourmash-examples/issues?q=is%3Aissue+is%3Aopen+%27frontpage%3A+True%27).

screenshots should also work, so img etc. like this: 
<img width="624" alt="Screen Shot 2022-05-19 at 6 15 16 AM" src="https://user-images.githubusercontent.com/51016/169303662-d4910147-c143-40f0-8039-9a2d8c56df7d.png">


at end: [http://github.com/ribbity-org/ribbity](http://github.com/ribbity-org/ribbity)

